# Encrypt RSA

Encrypt RSA provides public-keys (asymmetrical) encryption method plugins for the Encrypt module, using RSA algorithm. These plugins offer a variety of solutions to use public/private key to encrypt—and send—your date safely.


For a full description of the module, visit the
[project page](https://www.drupal.org/project/encrypt_rsa).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/encrypt_rsa).


## Requirements (required)

This module requires the following modules:

- [Encrypt](https://www.drupal.org/project/encrypt)
- [Asymmetric (private/public) Keys](https://www.drupal.org/project/key_assymetric)
- [Key](https://www.drupal.org/project/key)

### Libraries
- [phpseclib](https://phpseclib.com/)

## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration (required)

1. After installing and enabling the module, make sure you have either a private or public RSA key available for use.
2. Create a key of type "PEM Private key" or "PEM Public key" under `/admin/config/system/keys`, depending on your key type.
3. Create an encryption profile under `/admin/config/system/encryption/profiles` using "Private RSA" or "Public RSA" encryption methods.
   1. "Private OpenSSL Seal" and "Public OpenSSL Seal" are also available and should be used under your discretion.


## Usage

1. In your code, load the encryption profile entity via `entity_type.manager` service and use the following examples to encrypt/decrypt.
   ```php
   $profile->getEncryptionMethod()->encrypt($text_to_encrypt, $profile->getEncryptionKey()->getKeyValue());
   $profile->getEncryptionMethod()->decrypt($text_to_decrypt, $profile->getEncryptionKey()->getKeyValue());
   ```
   The variable `$text_to_decrypt` must be a base64-encoded string. `encrypt()` returns a base64-encoded string.
2. Consult the module's tests for code usage.
